import Vue from "vue";
import Vuex from "vuex";
import { checkToken, User } from "@/config/api.js";
import { set } from "@/config/db.js"; //缓存操作
import audioBg from "./modules/audioBg";
import videoPlay from "./modules/videoPlay";
Vue.use(Vuex);

const store = new Vuex.Store({
  state: {
    isAuth: "", // 默认为
    isBind: "",
    pageRouterReport: "", //报告详情的路径
    pageRouterActivity: "", //活动详情的路径
  },
  mutations: {
    globalData(state, payload) {
      state.isAuth = payload.IsAuth;
      state.isBind = payload.IsBind;
    },
    setRouterReport(state, payload) {
      state.pageRouterReport = payload;
    },
    setRouterActivity(state, payload) {
      state.pageRouterActivity = payload;
    },
  },
  actions: {
    checkHandle(context, navigateUrl = "") {
      return new Promise((resolve, reject) => {
        checkToken()
          .then((res) => {
            if (res.Ret === 200) {
              context.commit("globalData", res.Data);
              if (navigateUrl != "noGO") {
                if (!res.Data.IsAuth && !res.Data.IsBind) {
                  //已授权已绑定
                  if (navigateUrl) {
                    uni.navigateTo({
                      url: navigateUrl,
                    });
                  }
                } else if (res.Data.IsAuth) {
                  //未授权
                  uni.navigateTo({
                    url: "/pageMy/authGuide/authGuide",
                  });
                } else if (res.Data.IsBind && !res.Data.IsAuth) {
                  //已授权未绑定
                  uni.redirectTo({
                    url: "/pageMy/login/login",
                  });
                }
              }
              resolve();
            }
          })
          .catch((err) => {
            reject(err);
          });
      });
    },
    //获取用户的pv/uv
    statistics(type, payload) {
      return new Promise((resolve, reject) => {
        User.pageHistory(payload)
          .then((res) => {
            if (res.Ret === 200) {
              resolve(res.Data);
            }
          })
          .catch((err) => {
            reject(err);
          });
      });
    },
  },
  getters: {},
  modules: { audioBg, videoPlay },
});

export default store;
